@@ -28,7 +28,6 @@
 #include <glib/gi18n.h>
 #endif
 #include <glade/glade.h>
-#include <libgnome/libgnome.h>
 
 #include "htmlcolor.h"
 #include "htmlcolorset.h"
@@ -78,9 +77,9 @@ url_changed (GtkWidget *w, GtkHTMLEditLinkProperties *d)
 	tmp = g_strdup (url);
 	if (tmp && *tmp)
 		p = strchr (tmp, '\n');
-	if (p) 
+	if (p)
 		*p = 0;
-	
+
 	desc = gtk_entry_get_text (GTK_ENTRY (d->entry_description));
 	if (d->selection)
 		html_engine_set_link (d->cd->html->engine, url);
@@ -123,7 +122,7 @@ description_changed (GtkWidget *w, GtkHTMLEditLinkProperties *d)
 		}
 
 		html_engine_paste_link (e, tmp, len, gtk_entry_get_text (GTK_ENTRY (d->entry_url)));
-		d->insert_object = e->cursor->object; 
+		d->insert_object = e->cursor->object;
 		d->insert_end_offset = d->insert_start_offset + len;
 
 		g_free (tmp);
@@ -156,7 +155,7 @@ link_set_ui (GtkHTMLEditLinkProperties *d)
 			gtk_entry_set_text (GTK_ENTRY (d->entry_url), url);
 			gtk_widget_hide (d->label_description);
 			gtk_widget_hide (d->entry_description);
-		
+
 			if (HTML_IS_IMAGE (d->insert_object)) {
 				d->insert_start_offset = 0;
 				d->insert_end_offset = 1;
@@ -174,9 +173,11 @@ link_set_ui (GtkHTMLEditLinkProperties *d)
 				d->insert_start_offset = d->insert_end_offset = 0;
 			else
 				d->insert_start_offset = d->insert_end_offset = e->cursor->offset;
-		
+
 			gtk_entry_set_text (GTK_ENTRY (d->entry_url), "http://");
 		}
+
+		g_free (url);
 	}
 
 	d->disable_change = FALSE;
@@ -196,7 +197,7 @@ test_url_clicked (GtkWidget *w, GtkHTMLEditLinkProperties *d)
 	const char *url = gtk_entry_get_text (GTK_ENTRY (d->entry_url));
 
 	if (url)
-		gnome_url_show (url, NULL);
+		gtk_show_uri (NULL, url, GDK_CURRENT_TIME, NULL);
 }
 
 static GtkWidget *
