@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -26,11 +26,11 @@
 #else
 #include <glib/gi18n.h>
 #endif
-#include <gnome.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include "replace.h"
 #include "dialog.h"
 #include "htmlengine.h"
+#include "gtkhtml-private.h"
+
 
 struct _GtkHTMLReplaceAskDialog {
 	GtkDialog  *dialog;
@@ -87,7 +87,8 @@ ask_dialog_new (HTMLEngine *e)
 	d->engine = e;
 	d->finished = FALSE;
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (d->dialog), ICONDIR "/search-and-replace-24.png");
+	gtk_window_set_icon_name (GTK_WINDOW (d->dialog), "gtk-find-and-replace");
+
 	g_signal_connect (d->dialog, "response", G_CALLBACK (ask_dialog_response), d);
 
 	return d;
@@ -141,8 +142,11 @@ replace_dialog_response (GtkDialog *dialog, gint response_id, GtkHTMLReplaceDial
 				     GTK_TOGGLE_BUTTON (d->backward)->active == 0, FALSE,
 				     ask, d);
 		break;
-	case GTK_RESPONSE_CANCEL:
+	case GTK_RESPONSE_DELETE_EVENT:
 	case GTK_RESPONSE_CLOSE:
+	case GTK_RESPONSE_CANCEL:
+		d->cd->replace_dialog = NULL;
+		gtk_html_replace_dialog_destroy (d);
 		gtk_widget_grab_focus (GTK_WIDGET (d->html));
 		break;
 	}
@@ -212,7 +216,7 @@ gtk_html_replace_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 	gtk_widget_show_all (table);
 	gtk_widget_show_all (hbox);
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog->dialog), ICONDIR "/search-and-replace-24.png");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog->dialog), "gtk-find-and-replace");
 
 	gtk_widget_grab_focus (dialog->entry_search);
 
@@ -228,7 +232,6 @@ gtk_html_replace_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 void
 replace (GtkHTMLControlData *cd)
 {
-	RUN_DIALOG (replace, _("Replace"));
-	gtk_html_replace_dialog_destroy (cd->replace_dialog);
-	cd->replace_dialog = NULL;
+	run_dialog (&cd->replace_dialog->dialog, cd->html, cd,
+		(DialogCtor) gtk_html_replace_dialog_new, _("Replace"));
 }
